##  Collect Data from Experts
After importing initial data, gather additional information from experts. Populate the attributes added by the AI governance and AI agent extensions to the meta model. For more details, see [Required Data](https://help.sap.com/docs/leanix/ea/ai-governance-and-adoption-collect-information?locale=en-US&state=PRODUCTION&version=CLOUD#loio275cea7b7a4410149e519582edf8acdd__required-data).
You can collect information from experts using these features:
  * Surveys: Create and send surveys with questions for AI-related fact sheet fields. Once a survey response is submitted, the corresponding fact sheet fields are updated. To learn how to use surveys, see [Surveys](https://help.sap.com/docs/leanix/ea/surveys?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX surveys streamline data collection and collaboration with seamless integration with fact sheets.").
  * To-dos: Assign to-dos to fact sheet owners to update data in fact sheets. To learn how to use to-dos, see [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos?locale=en-US&state=PRODUCTION&version=CLOUD "To-dos facilitate task delegation, collaboration, and governance and can be used to ensure data integrity and quality through transparent task management.").
